package com.sun.net.ssl;

import javax.net.ssl.SSLServerSocketFactory;
import javax.net.ssl.SSLSocketFactory;
import java.security.KeyManagementException;
import java.security.SecureRandom;
import java.security.NoSuchAlgorithmException;
import java.security.Provider;
import javax.net.ssl.SSLContext;

final class SSLContextSpiWrapper extends SSLContextSpi
{
    private SSLContext theSSLContext;
    
    SSLContextSpiWrapper(String protocol, Provider provider) throws NoSuchAlgorithmException {
        this.theSSLContext = SSLContext.getInstance(protocol, provider);
    }
    
    @Override
    protected void engineInit(KeyManager[] array, TrustManager[] array2, SecureRandom random) throws KeyManagementException {
        javax.net.ssl.KeyManager[] km;
        if (array != null) {
            km = new javax.net.ssl.KeyManager[array.length];
            int i = 0;
            int n = 0;
            while (i < array.length) {
                if (!(array[i] instanceof javax.net.ssl.KeyManager)) {
                    if ((array[i] instanceof X509KeyManager)) {
                        km[n] = new X509KeyManagerJavaxWrapper((X509KeyManager)array[i]);
                        ++n;
                    }
                }
                else {
                    km[n] = (javax.net.ssl.KeyManager)array[i];
                    ++n;
                }
                ++i;
            }
            if (n != i) {
                km = (javax.net.ssl.KeyManager[])(javax.net.ssl.KeyManager[])SSLSecurity.truncateArray(km, new javax.net.ssl.KeyManager[n]);
            }
        }
        else {
            km = null;
        }
        javax.net.ssl.TrustManager[] tm;
        if (array2 != null) {
            tm = new javax.net.ssl.TrustManager[array2.length];
            int j = 0;
            int n2 = 0;
            while (j < array2.length) {
                if (!(array2[j] instanceof javax.net.ssl.TrustManager)) {
                    if ((array2[j] instanceof X509TrustManager)) {
                        tm[n2] = new X509TrustManagerJavaxWrapper((X509TrustManager)array2[j]);
                        ++n2;
                    }
                }
                else {
                    tm[n2] = (javax.net.ssl.TrustManager)array2[j];
                    ++n2;
                }
                ++j;
            }
            if (n2 != j) {
                tm = (javax.net.ssl.TrustManager[])(javax.net.ssl.TrustManager[])SSLSecurity.truncateArray(tm, new javax.net.ssl.TrustManager[n2]);
            }
        }
        else {
            tm = null;
        }
        this.theSSLContext.init(km, tm, random);
    }
    
    @Override
    protected SSLSocketFactory engineGetSocketFactory() {
        return this.theSSLContext.getSocketFactory();
    }
    
    @Override
    protected SSLServerSocketFactory engineGetServerSocketFactory() {
        return this.theSSLContext.getServerSocketFactory();
    }
}
